@@ -17,11 +17,11 @@ function(xy, delta, symmetric = TRUE)
 
 # add axes to a map
 "map.axes" <-
-function()
+function(...)
 {
-  axis(1)
-  axis(2)
-  box()
+  axis(1, ...)
+  axis(2, ...)
+  box(...)
   invisible()
 }
 
@@ -31,7 +31,7 @@ function (x = world.cities, country = "", label = NULL, minpop = 0,
   parameters = NULL, orientation = NULL, pch = 1, ...) 
 {
   if (missing(x)) {
-    data("world.cities", package = "maps", envir = environment())	# uses lazy evaluation
+    # data("world.cities", package = "maps")	# uses lazy evaluation
     world.cities <- get("world.cities")
   }
   usr <- par("usr")
